#!/usr/bin/env python
# coding: utf-8

# symbol explanation:
# quantum subspaces:
# G: {|1>} (see Fig. A1 in the publication https://arxiv.org/abs/2401.12395)
# H: {|6>, |7>, |8>}
# I: {|9>, |10>, |11>}
# J: {|12>, |13>}
# Jb: {|4>}
# F: {|14>, |15>}
# Jb: {|5>, |16>}
# functions:
# X2Y() with X and Y belong to quantum subspaces: They return Clebsch-Gordan coefficient matrices from subpace X to subspece Y.

from arc import *

atom = Rubidium87()

def G2H(f1, f2, mf1=2, mf2=1, q=-1):
    
    n1=5
    l1=0
    j1=1/2

    n2=5
    l2=1
    j2=3/2

    return atom.getDipoleMatrixElementHFS(n1, l1, j1, f1, mf1, n2, l2, j2, f2, mf2, q, s=0.5)

def H2I(f1, f2, mf1=1, mf2=1, q=0):
    
    n1=5
    l1=1
    j1=3/2

    n2=4
    l2=2
    j2=3/2

    return atom.getDipoleMatrixElementHFS(n1, l1, j1, f1, mf1, n2, l2, j2, f2, mf2, q, s=0.5)

def I2J(f1, f2, mf1=1, mf2=0, q=-1):
    
    n1=4
    l1=2
    j1=3/2

    n2=5
    l2=1
    j2=1/2

    return atom.getDipoleMatrixElementHFS(n1, l1, j1, f1, mf1, n2, l2, j2, f2, mf2, q, s=0.5)

def I2Jb(f1, f2, mf1=1, mf2=2, q=1):
    
    n1=4
    l1=2
    j1=3/2

    n2=5
    l2=1
    j2=1/2

    return atom.getDipoleMatrixElementHFS(n1, l1, j1, f1, mf1, n2, l2, j2, f2, mf2, q, s=0.5)

def J2F(f1, f2, mf1=0, mf2=-1, q=-1):
    
    n1=5
    l1=1
    j1=1/2


    n2=5
    l2=0
    j2=1/2

    return atom.getDipoleMatrixElementHFS(n1, l1, j1, f1, mf1, n2, l2, j2, f2, mf2, q, s=0.5)

def J2Fb(f1, f2, mf1=0, mf2=1, q=1):
    
    n1=5
    l1=1
    j1=1/2


    n2=5
    l2=0
    j2=1/2

    return atom.getDipoleMatrixElementHFS(n1, l1, j1, f1, mf1, n2, l2, j2, f2, mf2, q, s=0.5)



